package org.esupportail.portal.channels.CIntranet.actions.intranet;

import java.util.Hashtable;
import java.util.Vector;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.esupportail.portal.channels.CIntranet.beans.Document;
import org.esupportail.portal.channels.CIntranet.beans.DocumentFile;
import org.esupportail.portal.channels.CIntranet.data.DataControler;
import org.esupportail.portal.channels.CIntranet.data.DataException;
import org.esupportail.portal.channels.CIntranet.security.Security;
import org.esupportail.portal.channels.CIntranet.storage.IStorageControler;
import org.esupportail.portal.channels.CIntranet.storage.StorageException;
import org.esupportail.portal.channels.CIntranet.storage.StorageFactory;
import org.esupportail.portal.utils.channels.FrameWorkException;
import org.esupportail.portal.utils.channels.MainChannel;
import org.esupportail.portal.utils.channels.plugins.Message;
import org.esupportail.portal.utils.channels.plugins.MessageBean;
import org.jasig.portal.ChannelRuntimeData;
import org.jasig.portal.PortalException;

/**
 * DeleteDocument<br>
 * <br>
 * Cette classe prend en charge la suppression de plusieurs documents<br>
 * <br>
 * (c)Copyright <a href="http://www.esup-portail.org">ESup-Portail 2004</a><br>
 * @author <a href="mailto:mathieu.larchet@univ-nancy2.fr">Mathieu Larchet</a>
 * @version $Revision: 1.1.2.2 $
 * 
 */
public class DeleteDocuments extends AbstractAction {

    protected static Log log = LogFactory.getLog(DeleteDocuments.class);
    
    private boolean validation = false;
    
    /**
     * Constructeur
     * @param mainChannel La channel principale
     */
    public DeleteDocuments(MainChannel mainChannel) {
        super(mainChannel);
    }

    /**
     * Indique le niveau requis pour raliser cette action
     * Implements AbstractAction.getLevel() method
     * @return level Le niveau requis pour accder  cette action
     */
    public int getLevel() {
        return Security.ED_FULL;
    }

    /**
     * Etape 2/4 du cycle de vie de la SubChannel
     * Supprime des documents
     * Override SubChannel.init() method
     * @param rd Les runtimeData
     * @return Boolean TRUE si tout se passe bien, FALSE sinon
     * @throws PortalException
     * @throws FrameWorkException
     */
    public Boolean init(ChannelRuntimeData rd) throws PortalException, FrameWorkException {
        super.init(rd);
        if(super.initialize(rd).equals(Boolean.FALSE)) {
            return Boolean.FALSE;
        }
        if(log.isDebugEnabled()) {
            log.debug("DeleteDocuments::init()");
        }
        String [] ids = getRuntimeData().getParameterValues("selected");
        if(ids == null) {
            Hashtable parameters = new Hashtable();
            parameters.put("folder", folderid);
            Message.message(getMainChannel(), getRuntimeData(), new MessageBean("Aucun document s\u00E9lectionn\u00E9"), "viewfolder", parameters);
            return Boolean.FALSE;
        }
        DataControler data = new DataControler();
        IStorageControler store = StorageFactory.make(intranet.getRessource());
        Vector messages = new Vector();
        for(int i=0;i<ids.length;i++) {
            String id = ids[i];
            Document doc = null;
            try {
                doc = data.getDocument(intranet.getId(), id);
                if(level < Security.AUT_FULL) {
                    if(doc.isValid() && !doc.isPendingDeletion() && !doc.isPendingModification()) {
                        data.removeDocument(doc, true);
                        messages.add(new MessageBean(doc.getName() + " : Suppression en attente de validation", Message.WARNING));
                    }
                }
                else {
                    if(doc.isValid() && !doc.isPendingDeletion() && !doc.isPendingModification()) {
                        data.removeDocument(doc, false);
                        if(doc instanceof DocumentFile) {
                            store.destroyDocument(intranet.getId(), doc);
                        }
                        data.commit();
                        data.close();
                        messages.add(new MessageBean(doc.getName() + " : Document supprim\u00E9", Message.INFO));
                    }
                }
            }
            catch(DataException e) {
                log.error("DeleteDocuments::init() : DataException:\n" + e);
                messages.add(new MessageBean(doc.getName() + " : " + e.getMessage()));
            }
            catch(StorageException e) {
                log.error("DeleteDocuments::init() : StorageException :\n" + e);
                data.rollback();
                data.close();
                messages.add(new MessageBean(doc.getName() + " : " + e.getMessage()));
            }
        }
        if(!messages.isEmpty()) {
            Hashtable parameters = new Hashtable();
            parameters.put("folder", folderid);
            Message.message(getMainChannel(), getRuntimeData(), messages, "viewfolder", parameters);
            return Boolean.FALSE;
        }
        getRuntimeData().setParameter("folder", folderid);
        getMainChannel().redirect(getRuntimeData(), "viewfolder");
        return Boolean.FALSE;
    }
}
